==> haskell-hspec-hedgehog-0.0.1.2-323-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-6WoWOYTm9KNLlasSzH4YNc
key:                  hspec-hedgehog-0.0.1.2-6WoWOYTm9KNLlasSzH4YNc
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  b2f6964e74ef748639766891074a39ba
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-6WoWOYTm9KNLlasSzH4YNc
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-KXTisc688NGHRnxG3vFYz5 base-4.17.2.1
    hedgehog-1.4-CYZXipsPG6gD0EAstP7kye
    hspec-2.11.0-D7VULxXcWAEGlCKVY5WpWR
    hspec-core-2.11.0-KKyDu2lUEjtcjCkgc7Z4u
    splitmix-0.1.1-IId0Fmc3alN5VLc8IaVn2n

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-hedgehog-0.0.1.2-324-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-LJ7S1NOtEQE7QYgnUwt11y
key:                  hspec-hedgehog-0.0.1.2-LJ7S1NOtEQE7QYgnUwt11y
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  0fe505e55de729fc243edbf66f00b471
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-LJ7S1NOtEQE7QYgnUwt11y
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-2A88Zj501Le65aGYfSmEOh base-4.17.2.1
    hedgehog-1.4-9ewWiZOaL8I936vzoYXugS
    hspec-2.11.0-KMeCyPXNLcx497UDdZVCwx
    hspec-core-2.11.0-3BrRykY5ZAxJNZLSrty7KG
    splitmix-0.1.1-2v6KpeX3xvuAouXBHztuEW

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
